# Generated by Django 4.1.7 on 2023-03-01 16:22

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('oasis_auth', '0003_userprofile_quota_userprofile_segment'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='userprofile',
            name='quota',
        ),
    ]
