{%  load i18n %}
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
</head>
<body>
<p>{% translate "Hello"%}, {{ customer_name }}</p>
<p>{% blocktranslate %}Thank you for use the <strong>CADEFIHUILA's</strong> transactional portal. Below, you will find the new password for your login:{% endblocktranslate %}</p>
<p>
    <h2 style="text-align: center;">{{ new_password }}</h2>
</p>
<p>
    <label style="font-size: 8px;">
        {% blocktranslate %}This email was generated automatically at {{ email_datetime }} with id {{ email_id }}. Please do not answer it.{% endblocktranslate %}
    </label>
</p>
</body>
</html>