# Generated by Django 4.1 on 2023-01-18 20:03

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('oasis_auth', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='userprofile',
            name='first_name',
        ),
        migrations.RemoveField(
            model_name='userprofile',
            name='last_name',
        ),
    ]
