# Generated by Django 4.1.7 on 2023-03-01 16:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis_auth', '0002_remove_userprofile_first_name_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='userprofile',
            name='quota',
            field=models.DecimalField(decimal_places=2, default=0, max_digits=7),
        ),
        migrations.AddField(
            model_name='userprofile',
            name='segment',
            field=models.IntegerField(default=0),
        ),
    ]
